package Locale::CLDR::Locales::Ff::Any;

# This file auto generated
#	on Sun 24 Apr  8:27:08 am GMT

use version;

our $VERSION = version->declare('v0.29.0');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::Ff');

no Moo;

1;
